aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMartin Mathieson <martin.mathieson@keysight.com>2020-08-29 20:00:42 +0100
committerDario Lombardo <lomato@gmail.com>2020-08-29 21:32:39 +0000
commit4c9f59ee56664a491debe6fc97c087eec20ab5e0 (patch)
tree04b42d2f31a9f0fbaa345705419ac5aa350b00df
parentb8a773dddc50b4c321f060c8a4f8aa12f851f05a (diff)
Fix more spelling errors in dissector strings.
A second batch of spelling errors, detected using a script that uses pyspellcheck and a Wireshark-specific dictionary file. I will take at least one more pass through the dissectors, as further improvements are made to the script.
-rw-r--r--epan/dissectors/packet-ieee1722.c4
-rw-r--r--epan/dissectors/packet-ieee1905.c10
-rw-r--r--epan/dissectors/packet-ieee80211-radiotap.c4
-rw-r--r--epan/dissectors/packet-ieee80211.c52
-rw-r--r--epan/dissectors/packet-ieee802154.c2
-rw-r--r--epan/dissectors/packet-ipmi-transport.c6
-rw-r--r--epan/dissectors/packet-ipmi-vita.c4
-rw-r--r--epan/dissectors/packet-isakmp.c4
-rw-r--r--epan/dissectors/packet-iso8583.c2
-rw-r--r--epan/dissectors/packet-isup.c12
-rw-r--r--epan/dissectors/packet-ixveriwave.c8
-rw-r--r--epan/dissectors/packet-knxip.c2
-rw-r--r--epan/dissectors/packet-l2tp.c18
-rw-r--r--epan/dissectors/packet-lat.c2
-rw-r--r--epan/dissectors/packet-lbmc.c2
-rw-r--r--epan/dissectors/packet-lldp.c2
-rw-r--r--epan/dissectors/packet-llrp.c2
-rw-r--r--epan/dissectors/packet-m3ua.c2
-rw-r--r--epan/dissectors/packet-mih.c2
-rw-r--r--epan/dissectors/packet-mip6.c2
-rw-r--r--epan/dissectors/packet-mmse.c2
-rw-r--r--epan/dissectors/packet-mpeg-descriptor.c10
-rw-r--r--epan/dissectors/packet-mswsp.c6
-rw-r--r--epan/dissectors/packet-mtp2.c2
-rw-r--r--epan/dissectors/packet-nas_5gs.c2
-rw-r--r--epan/dissectors/packet-netflow.c10
-rw-r--r--epan/dissectors/packet-netmon.c2
-rw-r--r--epan/dissectors/packet-nfapi.c28
-rw-r--r--epan/dissectors/packet-nsrp.c2
-rw-r--r--epan/dissectors/packet-obex.c2
-rw-r--r--epan/dissectors/packet-opa-mad.c4
-rw-r--r--epan/dissectors/packet-pcep.c8
32 files changed, 110 insertions, 110 deletions
diff --git a/epan/dissectors/packet-ieee1722.c b/epan/dissectors/packet-ieee1722.c
index ed8b8491aa..a8a6e790b2 100644
--- a/epan/dissectors/packet-ieee1722.c
+++ b/epan/dissectors/packet-ieee1722.c
@@ -2006,7 +2006,7 @@ static int dissect_1722_ntscf (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
};
col_set_str(pinfo->cinfo, COL_PROTOCOL, "NTSCF");
- col_set_str(pinfo->cinfo, COL_INFO, "AVTP Non-Time-Syncronous Control Format");
+ col_set_str(pinfo->cinfo, COL_INFO, "AVTP Non-Time-Synchronous Control Format");
ti_ntscf = proto_tree_add_item(tree, proto_1722_ntscf, tvb, 0, -1, ENC_NA);
tree_ntscf = proto_item_add_subtree(ti_ntscf, ett_1722_ntscf);
@@ -2134,7 +2134,7 @@ static int dissect_1722_tscf (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
gint captured_payload_length;
col_set_str(pinfo->cinfo, COL_PROTOCOL, "TSCF");
- col_set_str(pinfo->cinfo, COL_INFO, "AVTP Time-Syncronous Control Format");
+ col_set_str(pinfo->cinfo, COL_INFO, "AVTP Time-Synchronous Control Format");
ti_tscf = proto_tree_add_item(tree, proto_1722_tscf, tvb, 0, -1, ENC_NA);
tree_tscf = proto_item_add_subtree(ti_tscf, ett_1722_tscf);
diff --git a/epan/dissectors/packet-ieee1905.c b/epan/dissectors/packet-ieee1905.c
index 98865aa2b1..de6048ba6e 100644
--- a/epan/dissectors/packet-ieee1905.c
+++ b/epan/dissectors/packet-ieee1905.c
@@ -5978,8 +5978,8 @@ dissect_cac_termination(tvbuff_t *tvb, packet_info *pinfo _U_,
static const range_string cac_completion_status_rvals[] = {
{ 0, 0, "Successful" },
{ 1, 1, "Radar detected" },
- { 2, 2, "CAC not supportted as requested" },
- { 3, 3, "Radio too busy to peform CAC" },
+ { 2, 2, "CAC not supported as requested" },
+ { 3, 3, "Radio too busy to perform CAC" },
{ 4, 4, "Request was considered non conformant to regulations in country of operation" },
{ 5, 5, "Other error" },
{ 6, 255, "Reserved" },
@@ -6849,7 +6849,7 @@ dissect_dscp_mapping_table(tvbuff_t *tvb, packet_info *pinfo _U_,
static const range_string r2_error_code_rvals[] = {
{ 0, 0, "Reserved" },
{ 1, 1, "Service Prioritization Rule not found" },
- { 2, 2, "Number of Service Prioritization Rules reaced the max supported" },
+ { 2, 2, "Number of Service Prioritization Rules reached the max supported" },
{ 3, 3, "Default PCP or VLAN ID not provided" },
{ 4, 4, "Reserved" },
{ 5, 5, "Number of unique VID exceeds maximum supported" },
@@ -7068,7 +7068,7 @@ dissect_r2_steering_request(tvbuff_t *tvb, packet_info *pinfo _U_,
amb_list = proto_tree_add_subtree(tree, tvb, offset, 6 * sta_list_count,
ett_r2_steering_sta_list, NULL,
- "AMB cabable STA list");
+ "AMB capable STA list");
while (sta_list_count > 0) {
proto_tree_add_item(amb_list, hf_ieee1905_r2_steering_sta_mac, tvb,
offset, 6, ENC_NA);
@@ -8880,7 +8880,7 @@ proto_register_ieee1905(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_l2_neighbor_intf_count,
- { "L2 neighbor interfae count", "ieee1905.l2_neighbor.intf_count",
+ { "L2 neighbor interface count", "ieee1905.l2_neighbor.intf_count",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ieee1905_l2_local_intf_mac_addr,
diff --git a/epan/dissectors/packet-ieee80211-radiotap.c b/epan/dissectors/packet-ieee80211-radiotap.c
index 4289fefb65..324fc4c5c6 100644
--- a/epan/dissectors/packet-ieee80211-radiotap.c
+++ b/epan/dissectors/packet-ieee80211-radiotap.c
@@ -3287,7 +3287,7 @@ void proto_register_radiotap(void)
{&hf_radiotap_present_l_sig,
{"L-SIG", "radiotap.present.l_sig",
FT_BOOLEAN, 32, TFS(&tfs_present_absent), RADIOTAP_MASK(L_SIG),
- "Specifies whther or not the L-SIG field is present", HFILL}},
+ "Specifies whether or not the L-SIG field is present", HFILL}},
{&hf_radiotap_present_tlv,
{"TLVs", "radiotap.present.tlv",
@@ -4478,7 +4478,7 @@ void proto_register_radiotap(void)
NULL, HFILL}},
{&hf_radiotap_midamble_periodicity,
- {"midamble periodicty", "radiotap.he.data_6.midamble_periodicity",
+ {"midamble periodicity", "radiotap.he.data_6.midamble_periodicity",
FT_UINT16, BASE_HEX, VALS(he_midamble_periodicity_vals),
IEEE80211_RADIOTAP_HE_MIDAMBLE_PERIODICITY, NULL, HFILL}},
diff --git a/epan/dissectors/packet-ieee80211.c b/epan/dissectors/packet-ieee80211.c
index 7bb1a4ba93..315e469716 100644
--- a/epan/dissectors/packet-ieee80211.c
+++ b/epan/dissectors/packet-ieee80211.c
@@ -504,7 +504,7 @@ const value_string ie_tag_num_vals[] = {
{ TAG_CISCO_CCX2, "Cisco CCX2" },
{ TAG_PXU, "Proxy Update" },
{ TAG_PXUC, "Proxy Update Confirmation"},
- { TAG_AUTH_MESH_PEERING_EXCH, "Auhenticated Mesh Perring Exchange" },
+ { TAG_AUTH_MESH_PEERING_EXCH, "Authenticated Mesh Peering Exchange" },
{ TAG_MIC, "MIC (Message Integrity Code)" },
{ TAG_DESTINATION_URI, "Destination URI" },
{ TAG_U_APSD_COEX, "U-APSD Coexistence" },
@@ -4259,7 +4259,7 @@ static int hf_ieee80211_tag_multiple_bssid_subelem_nontrans_profile = -1;
static int hf_ieee80211_tag_20_40_bc = -1;
static int hf_ieee80211_tag_20_40_bc_information_request = -1;
static int hf_ieee80211_tag_20_40_bc_forty_mhz_intolerant = -1;
-static int hf_ieee80211_tag_20_40_bc_20_mhz_bss_witdh_request = -1;
+static int hf_ieee80211_tag_20_40_bc_20_mhz_bss_width_request = -1;
static int hf_ieee80211_tag_20_40_bc_obss_scanning_exemption_request = -1;
static int hf_ieee80211_tag_20_40_bc_obss_scanning_exemption_grant = -1;
static int hf_ieee80211_tag_20_40_bc_reserved = -1;
@@ -5445,7 +5445,7 @@ static int hf_ieee80211_ff_handover_result = -1;
static int hf_ieee80211_ff_handover_reject_reason = -1;
static int hf_ieee80211_ff_destination_reds_aid = -1;
static int hf_ieee80211_ff_destination_aid = -1;
-static int hf_ieee80211_ff_realy_aid = -1;
+static int hf_ieee80211_ff_relay_aid = -1;
static int hf_ieee80211_ff_source_aid = -1;
static int hf_ieee80211_ff_timing_offset = -1;
static int hf_ieee80211_ff_sampling_frequency_offset = -1;
@@ -11674,9 +11674,9 @@ add_ff_destination_aid(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U_,
}
static guint
-add_ff_realy_aid(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U_, int offset)
+add_ff_relay_aid(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U_, int offset)
{
- proto_tree_add_item(tree, hf_ieee80211_ff_realy_aid, tvb, offset, 2, ENC_LITTLE_ENDIAN);
+ proto_tree_add_item(tree, hf_ieee80211_ff_relay_aid, tvb, offset, 2, ENC_LITTLE_ENDIAN);
return 2;
}
@@ -13303,7 +13303,7 @@ add_ff_action_dmg(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int offse
case DMG_ACTION_RLS_REQ:
offset += add_ff_dialog_token(tree, tvb, pinfo, offset);
offset += add_ff_destination_aid(tree, tvb, pinfo, offset);
- offset += add_ff_realy_aid(tree, tvb, pinfo, offset);
+ offset += add_ff_relay_aid(tree, tvb, pinfo, offset);
offset += add_ff_source_aid(tree, tvb, pinfo, offset);
break;
case DMG_ACTION_RLS_RES:
@@ -13313,12 +13313,12 @@ add_ff_action_dmg(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int offse
offset += add_ff_dialog_token(tree, tvb, pinfo, offset);
offset += add_ff_status_code(tree, tvb, pinfo, offset);
offset += add_ff_destination_aid(tree, tvb, pinfo, offset);
- offset += add_ff_realy_aid(tree, tvb, pinfo, offset);
+ offset += add_ff_relay_aid(tree, tvb, pinfo, offset);
offset += add_ff_source_aid(tree, tvb, pinfo, offset);
break;
case DMG_ACTION_RLS_TEARDOWN:
offset += add_ff_destination_aid(tree, tvb, pinfo, offset);
- offset += add_ff_realy_aid(tree, tvb, pinfo, offset);
+ offset += add_ff_relay_aid(tree, tvb, pinfo, offset);
offset += add_ff_source_aid(tree, tvb, pinfo, offset);
break;
case DMG_ACTION_RELAY_ACK_REQ:
@@ -18059,7 +18059,7 @@ dissect_20_40_bss_coexistence(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
static int * const ieee80211_20_40_bss_coexistence_fields[] = {
&hf_ieee80211_tag_20_40_bc_information_request,
&hf_ieee80211_tag_20_40_bc_forty_mhz_intolerant,
- &hf_ieee80211_tag_20_40_bc_20_mhz_bss_witdh_request,
+ &hf_ieee80211_tag_20_40_bc_20_mhz_bss_width_request,
&hf_ieee80211_tag_20_40_bc_obss_scanning_exemption_request,
&hf_ieee80211_tag_20_40_bc_obss_scanning_exemption_grant,
&hf_ieee80211_tag_20_40_bc_reserved,
@@ -28194,7 +28194,7 @@ proto_register_ieee80211(void)
FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
{&hf_ieee80211_beamform_feedback_seg_retrans_bitmap,
- {"Feedback segment Retansmission Bitmap", "wlan.beamform.feedback_seg_retrans_bitmap",
+ {"Feedback segment Retransmission Bitmap", "wlan.beamform.feedback_seg_retrans_bitmap",
FT_UINT8, BASE_HEX, NULL, 0,
NULL, HFILL }},
@@ -28293,7 +28293,7 @@ proto_register_ieee80211(void)
{&hf_ieee80211_ff_rm_repetitions,
{"Repetitions", "wlan.rm.repetitions",
FT_UINT16, BASE_DEC, NULL, 0,
- "Numer of Repetitions, 65535 indicates repeat until cancellation", HFILL }},
+ "Number of Repetitions, 65535 indicates repeat until cancellation", HFILL }},
{&hf_ieee80211_ff_rm_tx_power,
{"Transmit Power Used", "wlan.rm.tx_power",
@@ -28997,7 +28997,7 @@ proto_register_ieee80211(void)
NULL, HFILL }},
{&hf_ieee80211_tag_low_power_supported, /* DMG STA capa, bits [48] */
- {"Low Power SC PHY Supported", "wlan.dmg_capa.low_power_suuported",
+ {"Low Power SC PHY Supported", "wlan.dmg_capa.low_power_supported",
FT_BOOLEAN, 16, NULL, GENMASK(48-48, 48-48),
NULL, HFILL }},
@@ -29202,7 +29202,7 @@ proto_register_ieee80211(void)
NULL, HFILL }},
{&hf_ieee80211_tag_extendable,
- {"Extenedable", "wlan.ext_sched.extendable",
+ {"Extendable", "wlan.ext_sched.extendable",
FT_BOOLEAN, 16, NULL, 0x0200,
NULL, HFILL }},
@@ -29297,27 +29297,27 @@ proto_register_ieee80211(void)
NULL, HFILL }},
{&hf_ieee80211_tag_tx_mode,
- {"TX-Mode", "wlan.realy_trans_param.tx_mode",
+ {"TX-Mode", "wlan.relay_trans_param.tx_mode",
FT_BOOLEAN, 8, NULL, 0x04,
NULL, HFILL }},
{&hf_ieee80211_tag_link_change_interval,
- {"Link Change Interval", "wlan.realy_trans_param.link_change_interval",
+ {"Link Change Interval", "wlan.relay_trans_param.link_change_interval",
FT_UINT8, BASE_CUSTOM, CF_FUNC(allocation_duration_base_custom), 0xff,
NULL, HFILL }},
{&hf_ieee80211_tag_data_sensing_time,
- {"Data Sensing Time", "wlan.realy_trans_param.data_sensing_time",
+ {"Data Sensing Time", "wlan.relay_trans_param.data_sensing_time",
FT_UINT8, BASE_DEC, NULL, 0xff,
NULL, HFILL }},
{&hf_ieee80211_tag_first_period,
- {"First Period", "wlan.realy_trans_param.first_period",
+ {"First Period", "wlan.relay_trans_param.first_period",
FT_UINT16, BASE_DEC, NULL, 0xffff,
NULL, HFILL }},
{&hf_ieee80211_tag_second_period,
- {"Second Period", "wlan.realy_trans_param.second_period",
+ {"Second Period", "wlan.relay_trans_param.second_period",
FT_UINT16, BASE_DEC, NULL, 0xffff,
NULL, HFILL }},
@@ -29511,8 +29511,8 @@ proto_register_ieee80211(void)
FT_UINT16, BASE_DEC, NULL, 0,
NULL, HFILL }},
- {&hf_ieee80211_ff_realy_aid,
- {"Relay AID", "wlan.dmg.realy_aid",
+ {&hf_ieee80211_ff_relay_aid,
+ {"Relay AID", "wlan.dmg.relay_aid",
FT_UINT16, BASE_DEC, NULL, 0,
NULL, HFILL }},
@@ -29895,7 +29895,7 @@ proto_register_ieee80211(void)
NULL, HFILL }},
{&hf_ieee80211_tag_channel_measurement_feedback_sector_id,
- {"Channel Measurement Feedback Secotr ID", "wlan.ch_meas_fb.sector_id",
+ {"Channel Measurement Feedback Sector ID", "wlan.ch_meas_fb.sector_id",
FT_UINT8, BASE_DEC, NULL, 0xfc,
NULL, HFILL }},
@@ -33851,8 +33851,8 @@ proto_register_ieee80211(void)
FT_BOOLEAN, 8, NULL, 0x02,
NULL, HFILL }},
- {&hf_ieee80211_tag_20_40_bc_20_mhz_bss_witdh_request,
- {"20 MHz BSS Witdh Request", "wlan.20_40_bc.20_mhz_bss_witdh_request",
+ {&hf_ieee80211_tag_20_40_bc_20_mhz_bss_width_request,
+ {"20 MHz BSS Width Request", "wlan.20_40_bc.20_mhz_bss_width_request",
FT_BOOLEAN, 8, NULL, 0x04,
NULL, HFILL }},
@@ -38102,7 +38102,7 @@ proto_register_ieee80211(void)
0x80000000000, NULL, HFILL }},
{&hf_ieee80211_he_om_control_ul_mu_data_disable_rx_support,
- {"OM Control UL MU Data Disable RX Support", "wlan.ext_tag.he_mac_cap.om_cntl_ul_mu_data_disble_rx_support",
+ {"OM Control UL MU Data Disable RX Support", "wlan.ext_tag.he_mac_cap.om_cntl_ul_mu_data_disable_rx_support",
FT_BOOLEAN, 48, TFS(&tfs_supported_not_supported),
0x100000000000, NULL, HFILL }},
@@ -38749,11 +38749,11 @@ proto_register_ieee80211(void)
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{&hf_ieee80211_he_operation_channel_center_freq_0,
- {"Channel Center Frequency Segment 0", "wlan.ext_tag.he_operatoon.vht_op_info.chan_center_freq_seg_0",
+ {"Channel Center Frequency Segment 0", "wlan.ext_tag.he_operation.vht_op_info.chan_center_freq_seg_0",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{&hf_ieee80211_he_operation_channel_center_freq_1,
- {"Channel Center Frequency Segment 1", "wlan.ext_tag.he_operatoon.vht_op_info.chan_center_freq_seg_1",
+ {"Channel Center Frequency Segment 1", "wlan.ext_tag.he_operation.vht_op_info.chan_center_freq_seg_1",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{&hf_ieee80211_he_operation_max_colocated_bssid_indicator,
diff --git a/epan/dissectors/packet-ieee802154.c b/epan/dissectors/packet-ieee802154.c
index 6c2a24c587..15ee687093 100644
--- a/epan/dissectors/packet-ieee802154.c
+++ b/epan/dissectors/packet-ieee802154.c
@@ -6016,7 +6016,7 @@ void proto_register_ieee802154(void)
{ &hf_ieee802154_tsch_timeslot_length,
{ "Timeslot Length", "wpan.tsch.timeslot.length", FT_UINT24, BASE_DEC, NULL, 0x0,
- "Total length of the timeslot, including any unsused time after frame transmission", HFILL }},
+ "Total length of the timeslot, including any unused time after frame transmission", HFILL }},
{ &hf_ieee802154_tsch_channel_hopping,
{ "Channel Hopping IE", "wpan.channel_hopping", FT_NONE, BASE_NONE, NULL, 0x0,
diff --git a/epan/dissectors/packet-ipmi-transport.c b/epan/dissectors/packet-ipmi-transport.c
index 2377a12cf3..feabe60617 100644
--- a/epan/dissectors/packet-ipmi-transport.c
+++ b/epan/dissectors/packet-ipmi-transport.c
@@ -2925,13 +2925,13 @@ proto_register_ipmi_transport(void)
"ipmi.lanXX.num_dynamic_sets", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ipmi_trn_lan80_max_rtr_solicitation_delay,
- { "MAX_RTR_SOLICITATIOIN_DELAY",
+ { "MAX_RTR_SOLICITATION_DELAY",
"ipmi.lan80.max_rtr_sol_delay", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ipmi_trn_lan80_rtr_solicitation_interval,
- { "RTR_SOLICITATIOIN_INTERVAL",
+ { "RTR_SOLICITATION_INTERVAL",
"ipmi.lan80.rtr_sol_interval", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ipmi_trn_lan80_max_rtr_solicitations,
- { "MAX_RTR_SOLICITATIOINS",
+ { "MAX_RTR_SOLICITATIONS",
"ipmi.lan80.max_rtr_sols", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_ipmi_trn_lan80_dup_addr_detect_transmits,
{ "DupAddrDetectTransmits",
diff --git a/epan/dissectors/packet-ipmi-vita.c b/epan/dissectors/packet-ipmi-vita.c
index 489e97fe9a..7147d0f227 100644
--- a/epan/dissectors/packet-ipmi-vita.c
+++ b/epan/dissectors/packet-ipmi-vita.c
@@ -538,7 +538,7 @@ static hf_register_info hf_ipmi_vita[] = {
{ "Override State LED Function", "ipmi.vita.led.ovr.func",
FT_UINT8, BASE_DEC|BASE_RANGE_STRING, RVALS(str_vita_led_func), 0, NULL, HFILL }},
{ &hf_vita_led_ovr_duration,
- { "Override State On-Duration", "ipmi.vita.led.ovr.diration",
+ { "Override State On-Duration", "ipmi.vita.led.ovr.duration",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_vita_led_ovr_color,
{ "Override State Color", "ipmi.vita.led.ovr.color",
@@ -550,7 +550,7 @@ static hf_register_info hf_ipmi_vita[] = {
{ "Local Control LED Function", "ipmi.vita.led.loc.func",
FT_UINT8, BASE_DEC|BASE_RANGE_STRING, RVALS(str_vita_led_func), 0, NULL, HFILL }},
{ &hf_vita_led_loc_duration,
- { "Local Control On-Duration", "ipmi.vita.led.loc.diration",
+ { "Local Control On-Duration", "ipmi.vita.led.loc.duration",
FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
{ &hf_vita_led_loc_color,
{ "Local Control Color", "ipmi.vita.led.loc.color",
diff --git a/epan/dissectors/packet-iso8583.c b/epan/dissectors/packet-iso8583.c
index 502422f19a..6594657ec5 100644
--- a/epan/dissectors/packet-iso8583.c
+++ b/epan/dissectors/packet-iso8583.c
@@ -1014,7 +1014,7 @@ proto_register_iso8583(void)
{ &hf_iso8583_mti,
{ "MTI", "iso8583.mti",
FT_STRING, STR_ASCII, NULL , 0,
- "Message Type Idicator (MTI)", HFILL }
+ "Message Type Indicator (MTI)", HFILL }
},
{ &hf_iso8583_bitmap1,
{ "Bitmap 1", "iso8583.map1",
diff --git a/epan/dissectors/packet-isup.c b/epan/dissectors/packet-isup.c
index d635f66145..ed299b5b50 100644
--- a/epan/dissectors/packet-isup.c
+++ b/epan/dissectors/packet-isup.c
@@ -3050,7 +3050,7 @@ static int hf_japan_isup_dcr = -1;
static int hf_japan_isup_ecr = -1;
static int hf_japan_isup_ncr = -1;
static int hf_japan_isup_scr = -1;
-static int hf_japan_isup_collecting_metod = -1;
+static int hf_japan_isup_collecting_method = -1;
static int hf_japan_isup_tariff_rate_pres = -1;
static int hf_japan_isup_charge_area_nat_of_info_value = -1;
@@ -7741,7 +7741,7 @@ static const value_string japan_isup_charging_party_type_values[] = {
{ 0, NULL}
};
-static const value_string japan_isup_collecting_metod_values[] = {
+static const value_string japan_isup_collecting_method_values[] = {
{ 0, "Subscriber will be claimed" },
{ 0, NULL}
};
@@ -7779,7 +7779,7 @@ dissect_japan_chg_inf_type_acr(tvbuff_t *parameter_tvb, proto_tree *parameter_tr
/* Tariff collecting method and charging party type */
proto_tree_add_item(parameter_tree, hf_isup_extension_ind, parameter_tvb, offset, 1, ENC_BIG_ENDIAN);
proto_tree_add_item(parameter_tree, hf_japan_isup_charging_party_type, parameter_tvb, offset, 1, ENC_BIG_ENDIAN);
- proto_tree_add_item(parameter_tree, hf_japan_isup_collecting_metod, parameter_tvb, offset, 1, ENC_BIG_ENDIAN);
+ proto_tree_add_item(parameter_tree, hf_japan_isup_collecting_method, parameter_tvb, offset, 1, ENC_BIG_ENDIAN);
offset += 1;
}
}
@@ -11981,9 +11981,9 @@ proto_register_isup(void)
FT_STRING, BASE_NONE, NULL, 0x0,
NULL, HFILL }},
- { &hf_japan_isup_collecting_metod,
- { "Charging party type", "isup.japan.collecting_metod",
- FT_UINT8, BASE_DEC, VALS(japan_isup_collecting_metod_values), 0x0f,
+ { &hf_japan_isup_collecting_method,
+ { "Charging party type", "isup.japan.collecting_method",
+ FT_UINT8, BASE_DEC, VALS(japan_isup_collecting_method_values), 0x0f,
NULL, HFILL }},
{ &hf_japan_isup_tariff_rate_pres,
diff --git a/epan/dissectors/packet-ixveriwave.c b/epan/dissectors/packet-ixveriwave.c
index ae20cf1d3a..aec4411e6a 100644
--- a/epan/dissectors/packet-ixveriwave.c
+++ b/epan/dissectors/packet-ixveriwave.c
@@ -546,7 +546,7 @@ static int hf_radiotap_vw_errors_rx_bad_flow_payload_checksum = -1;
static int hf_radiotap_vw_errors_rx_illegal_vht_sig_value = -1;
static int hf_radiotap_vw_errors_rx_ip_checksum_error = -1;
static int hf_radiotap_vw_errors_rx_l4_checksum_error = -1;
-static int hf_radiotap_vw_errors_rx_l1_unsupported_faature = -1;
+static int hf_radiotap_vw_errors_rx_l1_unsupported_feature = -1;
static int hf_radiotap_vw_errors_rx_l1_packet_termination = -1;
static int hf_radiotap_vw_errors_rx_internal_error_bit15 = -1;
static int hf_radiotap_vw_errors_rx_wep_mic_miscompare = -1;
@@ -2890,7 +2890,7 @@ wlantap_dissect_octo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
&hf_radiotap_vw_errors_rx_illegal_vht_sig_value,
&hf_radiotap_vw_errors_rx_ip_checksum_error,
&hf_radiotap_vw_errors_rx_l4_checksum_error,
- &hf_radiotap_vw_errors_rx_l1_unsupported_faature,
+ &hf_radiotap_vw_errors_rx_l1_unsupported_feature,
&hf_radiotap_vw_errors_rx_l1_packet_termination,
&hf_radiotap_vw_errors_rx_internal_error_bit15,
&hf_radiotap_vw_errors_rx_wep_mic_miscompare,
@@ -4149,8 +4149,8 @@ framing signal deasserted. this is caused by software setting the drain all reg
{ &hf_radiotap_vw_errors_rx_l4_checksum_error,
{ "L4 (TCP/ICMP/IGMP/UDP) checksum error", "ixveriwave.errors.l4_checksum_error",
FT_BOOLEAN, 32, NULL, 0x00000800, NULL, HFILL } },
- { &hf_radiotap_vw_errors_rx_l1_unsupported_faature,
- { "Layer 1 Unsupported Feature", "ixveriwave.errors.l1_unsupported_faature",
+ { &hf_radiotap_vw_errors_rx_l1_unsupported_feature,
+ { "Layer 1 Unsupported Feature", "ixveriwave.errors.l1_unsupported_feature",
FT_BOOLEAN, 32, NULL, 0x00001000, NULL, HFILL } },
{ &hf_radiotap_vw_errors_rx_l1_packet_termination,
{ "Layer 1 Packet Termination", "ixveriwave.errors.l1_packet_termination",
diff --git a/epan/dissectors/packet-knxip.c b/epan/dissectors/packet-knxip.c
index 05d443935e..885e29a335 100644
--- a/epan/dissectors/packet-knxip.c
+++ b/epan/dissectors/packet-knxip.c
@@ -3701,7 +3701,7 @@ static void dissect_knxip_data( guint8 header_length, guint8 protocol_version _U
if( tree )
{
proto_item* unknown_item = knxip_tree_add_unknown_data( kip_tree, tvb, offset, remaining_len );
- expert_add_info_format( pinfo, unknown_item, KIP_ERROR, "Unexpexted trailing data" );
+ expert_add_info_format( pinfo, unknown_item, KIP_ERROR, "Unexpected trailing data" );
}
ok = 0;
diff --git a/epan/dissectors/packet-l2tp.c b/epan/dissectors/packet-l2tp.c
index 9f60be60a7..70af7d552c 100644
--- a/epan/dissectors/packet-l2tp.c
+++ b/epan/dissectors/packet-l2tp.c
@@ -765,7 +765,7 @@ static const value_string ericsson_avp_type_vals[] = {
{ ERICSSON_ABIS_LOWER_MODE, "Abis Lower Mode" },
{ ERICSSON_TEI_TO_SC_MAP, "TEI to SC Map" },
{ ERICSSON_CHAN_STATUS_LIST, "Channel Status List" },
- { ERICSSON_EXT_PROTO_VERSION, "Extended Protoocl Version" },
+ { ERICSSON_EXT_PROTO_VERSION, "Extended Protocol Version" },
{ ERICSSON_CHAN_STATUS_LIST2, "Channel Status List 2" },
{ 0, NULL }
};
@@ -3462,20 +3462,20 @@ proto_register_l2tp(void)
"Minimum Data Rate Downstream Low-Power in bits per seconds", HFILL }},
{ &hf_l2tp_broadband_maximum_interleaving_delay_up,
- { "Maximum Interleaving Dalay Upstream", "l2tp.broadband.maximum_interleaving_delay_up", FT_UINT32, BASE_DEC, NULL, 0x0,
- "Maximum Interleaving Dalay Upstream in ms", HFILL }},
+ { "Maximum Interleaving Delay Upstream", "l2tp.broadband.maximum_interleaving_delay_up", FT_UINT32, BASE_DEC, NULL, 0x0,
+ "Maximum Interleaving Delay Upstream in ms", HFILL }},
{ &hf_l2tp_broadband_actual_interleaving_delay_up,
- { "Actual Interleaving Dalay Upstream", "l2tp.broadband.actual_interleaving_delay_up", FT_UINT32, BASE_DEC, NULL, 0x0,
- "Actual Interleaving Dalay Upstream in ms", HFILL }},
+ { "Actual Interleaving Delay Upstream", "l2tp.broadband.actual_interleaving_delay_up", FT_UINT32, BASE_DEC, NULL, 0x0,
+ "Actual Interleaving Delay Upstream in ms", HFILL }},
{ &hf_l2tp_broadband_maximum_interleaving_delay_down,
- { "Maximum Interleaving Dalay Downstream", "l2tp.broadband.maximum_interleaving_delay_down", FT_UINT32, BASE_DEC, NULL, 0x0,
- "Maximum Interleaving Dalay Downstream in ms", HFILL }},
+ { "Maximum Interleaving Delay Downstream", "l2tp.broadband.maximum_interleaving_delay_down", FT_UINT32, BASE_DEC, NULL, 0x0,
+ "Maximum Interleaving Delay Downstream in ms", HFILL }},
{ &hf_l2tp_broadband_actual_interleaving_delay_down,
- { "Actual Interleaving Dalay Downstream", "l2tp.broadband.actual_interleaving_delay_down", FT_UINT32, BASE_DEC, NULL, 0x0,
- "Actual Interleaving Dalay Downstream in ms", HFILL }},
+ { "Actual Interleaving Delay Downstream", "l2tp.broadband.actual_interleaving_delay_down", FT_UINT32, BASE_DEC, NULL, 0x0,
+ "Actual Interleaving Delay Downstream in ms", HFILL }},
{ &hf_l2tp_broadband_access_loop_encapsulation,
{ "Access Loop Encapsulation", "l2tp.broadband.access_loop_encapsulation", FT_NONE, BASE_NONE, NULL, 0x0,
diff --git a/epan/dissectors/packet-lat.c b/epan/dissectors/packet-lat.c
index e8f7643222..c9973bf77e 100644
--- a/epan/dissectors/packet-lat.c
+++ b/epan/dissectors/packet-lat.c
@@ -1854,7 +1854,7 @@ proto_register_lat(void)
8, NULL, 0x02, NULL, HFILL}},
{ &hf_lat_obj_node_name,
- { "Destinaton node name", "lat.obj_node.name", FT_UINT_STRING,
+ { "Destination node name", "lat.obj_node.name", FT_UINT_STRING,
BASE_NONE, NULL, 0x0,
NULL, HFILL}},
diff --git a/epan/dissectors/packet-lbmc.c b/epan/dissectors/packet-lbmc.c
index 1361f6f1bc..70cbad568a 100644
--- a/epan/dissectors/packet-lbmc.c
+++ b/epan/dissectors/packet-lbmc.c
@@ -4366,7 +4366,7 @@ static const value_string lbmc_umq_idx_cmd_response_error_code[] =
{ UMQUEUE_RCV_IDX_CMD_EAUTHFAIL, "Authorization failure" },
{ LBM_UMQ_ULB_RCV_IDX_CMD_EIDXNOTASSIGNED, "Index not assigned" },
{ LBM_UMQ_ULB_RCV_IDX_CMD_EIDXINELIGIBLE, "Receiver ineligible for index" },
- { LBM_UMQ_ULB_RCV_IDX_CMD_EIDXINUSE, "Indes already assigned or unavailable" },
+ { LBM_UMQ_ULB_RCV_IDX_CMD_EIDXINUSE, "Index already assigned or unavailable" },
{ LBM_UMQ_ULB_RCV_IDX_CMD_EIDXALREADYASSIGNED, "Index already assigned to this receiver" },
{ 0x0, NULL }
};
diff --git a/epan/dissectors/packet-lldp.c b/epan/dissectors/packet-lldp.c
index a35e30825e..f1cc528acc 100644
--- a/epan/dissectors/packet-lldp.c
+++ b/epan/dissectors/packet-lldp.c
@@ -1068,7 +1068,7 @@ static const value_string operational_mau_type_values[] = {
#define HYTEC_MD__LINELOSS 4
#define HYTEC_MD__TX_CURRENT_OUTPUT_POWER_STR "Tx current output power"
-#define HYTEC_MD__RX_CURRENT_INPUT_POWER_STR "Rx current intput power"
+#define HYTEC_MD__RX_CURRENT_INPUT_POWER_STR "Rx current input power"
#define HYTEC_MD__RX_INPUT_SNR_STR "Rx input SNR"
#define HYTEC_MD__LINELOSS_STR "Lineloss"
diff --git a/epan/dissectors/packet-llrp.c b/epan/dissectors/packet-llrp.c
index e7fb84338c..b115456cdf 100644
--- a/epan/dissectors/packet-llrp.c
+++ b/epan/dissectors/packet-llrp.c
@@ -3814,7 +3814,7 @@ proto_register_llrp(void)
NULL, HFILL }},
{ &hf_llrp_soft_ver,
- { "Softwave version", "llrp.param.soft_ver", FT_UINT_STRING, BASE_NONE, NULL, 0,
+ { "Software version", "llrp.param.soft_ver", FT_UINT_STRING, BASE_NONE, NULL, 0,
NULL, HFILL }},
{ &hf_llrp_firm_ver,
diff --git a/epan/dissectors/packet-m3ua.c b/epan/dissectors/packet-m3ua.c
index a601832921..aaf166ed2d 100644
--- a/epan/dissectors/packet-m3ua.c
+++ b/epan/dissectors/packet-m3ua.c
@@ -2044,7 +2044,7 @@ proto_register_m3ua(void)
{ &hf_parameter_value, { "Parameter value", "m3ua.parameter_value", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL } },
{ &hf_parameter_padding, { "Padding", "m3ua.parameter_padding", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL } },
#if 0
- { &hf_parameter_trailer, { "Trailer", "m3ua.paramter_trailer", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL } },
+ { &hf_parameter_trailer, { "Trailer", "m3ua.parameter_trailer", FT_BYTES, BASE_NONE, NULL, 0x0, NULL, HFILL } },
#endif
{ &hf_network_appearance, { "Network appearance", "m3ua.network_appearance", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL } },
{ &hf_info_string, { "Info string", "m3ua.info_string", FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL } },
diff --git a/epan/dissectors/packet-mih.c b/epan/dissectors/packet-mih.c
index 8326888588..5127f9ca4c 100644
--- a/epan/dissectors/packet-mih.c
+++ b/epan/dissectors/packet-mih.c
@@ -838,7 +838,7 @@ static const value_string link_param_fdd_vals[] = {
static const value_string link_param_802_11_vals[] = {
{0, "RSSI"},
{1, "No QoS resource Available"},
-{2, "Multiast packet loss rate"},
+{2, "Multicast packet loss rate"},
{0, NULL}
};
diff --git a/epan/dissectors/packet-mip6.c b/epan/dissectors/packet-mip6.c
index 0bcedfdd94..5f6f741d66 100644
--- a/epan/dissectors/packet-mip6.c
+++ b/epan/dissectors/packet-mip6.c
@@ -4818,7 +4818,7 @@ proto_register_mip6(void)
},
{ &hf_pmip6_lra_u,
- { "unsolicited", "mip6.lri.unsolicated",
+ { "unsolicited", "mip6.lri.unsolicited",
FT_BOOLEAN, 8, TFS(&tfs_yes_no), 0x80,
"When set to 1, the LRA message is sent unsolicited", HFILL }
},
diff --git a/epan/dissectors/packet-mmse.c b/epan/dissectors/packet-mmse.c
index 69d1f6dfdf..6588ed0a57 100644
--- a/epan/dissectors/packet-mmse.c
+++ b/epan/dissectors/packet-mmse.c
@@ -172,7 +172,7 @@ static const value_string vals_mm_header_names[] = {
{ MM_CONTENT_HDR, "Content" },
{ MM_START_HDR, "X-Mms-Start" },
{ MM_ADDITIONAL_HDR, "Additional-headers" },
- { MM_DISTRIBUION_IND_HDR, "X-Mms-Distribution-Indcator" },
+ { MM_DISTRIBUION_IND_HDR, "X-Mms-Distribution-Indicator" },
{ MM_ELEMENT_DESCR_HDR, "X-Mms-Element-Descriptor" },
{ MM_LIMIT_HDR, "X-Mms-Limit" },
diff --git a/epan/dissectors/packet-mpeg-descriptor.c b/epan/dissectors/packet-mpeg-descriptor.c
index a54accdfea..af09a21a7d 100644
--- a/epan/dissectors/packet-mpeg-descriptor.c
+++ b/epan/dissectors/packet-mpeg-descriptor.c
@@ -3430,17 +3430,17 @@ proto_register_mpeg_descriptor(void)
} },
{ &hf_mpeg_descr_avc_vid_constraint_set0_flag, {
- "Constraint Set0 Flag", "mpeg_descr.avc_vid.contraint_set0",
+ "Constraint Set0 Flag", "mpeg_descr.avc_vid.constraint_set0",
FT_UINT8, BASE_DEC, NULL, MPEG_DESCR_AVC_VID_CONSTRAINT_SET0_FLAG_MASK, NULL, HFILL
} },
{ &hf_mpeg_descr_avc_vid_constraint_set1_flag, {
- "Constraint Set1 Flag", "mpeg_descr.avc_vid.contraint_set1",
+ "Constraint Set1 Flag", "mpeg_descr.avc_vid.constraint_set1",
FT_UINT8, BASE_DEC, NULL, MPEG_DESCR_AVC_VID_CONSTRAINT_SET1_FLAG_MASK, NULL, HFILL
} },
{ &hf_mpeg_descr_avc_vid_constraint_set2_flag, {
- "Constraint Set2 Flag", "mpeg_descr.avc_vid.contraint_set2",
+ "Constraint Set2 Flag", "mpeg_descr.avc_vid.constraint_set2",
FT_UINT8, BASE_DEC, NULL, MPEG_DESCR_AVC_VID_CONSTRAINT_SET2_FLAG_MASK, NULL, HFILL
} },
@@ -4454,12 +4454,12 @@ proto_register_mpeg_descriptor(void)
} },
{ &hf_mpeg_descr_logon_initialize_capacity_type_flag_reserved, {
- "Capacity Type Flag Reserved", "mpeg_descr.logon_init.capactity_type_flag_reserved",
+ "Capacity Type Flag Reserved", "mpeg_descr.logon_init.capacity_type_flag_reserved",
FT_UINT8, BASE_DEC, NULL, MPEG_DESCR_LOGON_INITIALIZE_CAPACITY_TYPE_FLAG_RESERVED_MASK, NULL, HFILL
} },
{ &hf_mpeg_descr_logon_initialize_capacity_type_flag, {
- "Capacity Type Flag", "mpeg_descr.logon_init.capactity_type_flag",
+ "Capacity Type Flag", "mpeg_descr.logon_init.capacity_type_flag",
FT_UINT8, BASE_DEC, NULL, MPEG_DESCR_LOGON_INITIALIZE_CAPACITY_TYPE_FLAG_MASK, NULL, HFILL
} },
diff --git a/epan/dissectors/packet-mswsp.c b/epan/dissectors/packet-mswsp.c
index e5ad5104ef..e965796ba3 100644
--- a/epan/dissectors/packet-mswsp.c
+++ b/epan/dissectors/packet-mswsp.c
@@ -6584,7 +6584,7 @@ proto_register_mswsp(void)
{
&hf_mswsp_cscort_individual,
{
- "inidvidual", "mswsp.csort.individual",
+ "individual", "mswsp.csort.individual",
FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL
}
},
@@ -6605,14 +6605,14 @@ proto_register_mswsp(void)
{
&hf_mswsp_ctablecolumn_aggused,
{
- "AggreagateUsed", "mswsp.ctablecolumn.aggused",
+ "AggregateUsed", "mswsp.ctablecolumn.aggused",
FT_UINT8, BASE_HEX, NULL, 0, NULL, HFILL
}
},
{
&hf_mswsp_ctablecolumn_aggtype,
{
- "AggreagateType", "mswsp.ctablecolumn.aggtype",
+ "AggregateType", "mswsp.ctablecolumn.aggtype",
FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL
}
},
diff --git a/epan/dissectors/packet-mtp2.c b/epan/dissectors/packet-mtp2.c
index b7201ed71f..96f6c7e8bf 100644
--- a/epan/dissectors/packet-mtp2.c
+++ b/epan/dissectors/packet-mtp2.c
@@ -1105,7 +1105,7 @@ dissect_mtp2_bitstream(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
/* issue frame reset */
issue_frame_reset_info(tree, new_tvb);
/* prepare col_info string */
- col_info_str = "[Frame Reset in reassebmly]";
+ col_info_str = "[Frame Reset in reassembly]";
} else {
/* append the reassembled packet to the head of the packet list */
wmem_list_prepend(result->found_packets, prepare_data_for_found_packet(new_tvb,result->mtp2_remain_data.before_fh_unalignment_offset));
diff --git a/epan/dissectors/packet-nas_5gs.c b/epan/dissectors/packet-nas_5gs.c
index d457094958..1f8858799e 100644
--- a/epan/dissectors/packet-nas_5gs.c
+++ b/epan/dissectors/packet-nas_5gs.c
@@ -861,7 +861,7 @@ static const value_string nas_5gs_nw_feat_sup_emf_values[] = {
{ 0x0, "Emergency services fallback not supported" },
{ 0x1, "Emergency services fallback supported in NR connected to 5GCN only" },
{ 0x2, "Emergency services fallback supported in E-UTRA connected to 5GCN only" },
- { 0x3, "mergency services fallback supported in NR connected to 5GCN and E-UTRA connected to 5GCN" },
+ { 0x3, "Emergency services fallback supported in NR connected to 5GCN and E-UTRA connected to 5GCN" },
{ 0, NULL }
};
diff --git a/epan/dissectors/packet-netflow.c b/epan/dissectors/packet-netflow.c
index c4a558e554..10d36dec3e 100644
--- a/epan/dissectors/packet-netflow.c
+++ b/epan/dissectors/packet-netflow.c
@@ -1840,7 +1840,7 @@ static const value_string v10_template_types_niagara_networks[] = {
{ 102, "SslServerVersionText" },
{ 103, "SslServerCipher" },
{ 104, "SslServerCipherText" },
- { 105, "SslConnectionEncriptionType" },
+ { 105, "SslConnectionEncryptionType" },
{ 106, "SslServerCompressionMethod" },
{ 107, "SslServerSessionId" },
{ 108, "SslCertificateIssuer" },
@@ -3484,7 +3484,7 @@ static int hf_pie_niagara_networks_sslserverversion
static int hf_pie_niagara_networks_sslserverversiontext = -1;
static int hf_pie_niagara_networks_sslservercipher = -1;
static int hf_pie_niagara_networks_sslserverciphertext = -1;
-static int hf_pie_niagara_networks_sslconnectionencriptiontype = -1;
+static int hf_pie_niagara_networks_sslconnectionencryptiontype = -1;
static int hf_pie_niagara_networks_sslservercompressionmethod = -1;
static int hf_pie_niagara_networks_sslserversessionid = -1;
static int hf_pie_niagara_networks_sslcertificateissuer = -1;
@@ -11059,7 +11059,7 @@ dissect_v9_v10_pdu_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *pdutree,
break;
case ((VENDOR_NIAGARA_NETWORKS << 16) | 105):
- ti = proto_tree_add_item(pdutree, hf_pie_niagara_networks_sslconnectionencriptiontype,
+ ti = proto_tree_add_item(pdutree, hf_pie_niagara_networks_sslconnectionencryptiontype,
tvb, offset, length, ENC_UTF_8|ENC_NA);
break;
@@ -18633,8 +18633,8 @@ proto_register_netflow(void)
NULL, HFILL}
},
/* Niagara Networks, 47729 / 105 */
- {&hf_pie_niagara_networks_sslconnectionencriptiontype,
- {"SslConnectionEncriptionType", "cflow.pie.niagaranetworks.sslconnectionencriptiontype",
+ {&hf_pie_niagara_networks_sslconnectionencryptiontype,
+ {"SslConnectionEncryptionType", "cflow.pie.niagaranetworks.sslconnectionencryptiontype",
FT_STRING, STR_UNICODE, NULL, 0X0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-netmon.c b/epan/dissectors/packet-netmon.c
index c9bb661973..51f14c6158 100644
--- a/epan/dissectors/packet-netmon.c
+++ b/epan/dissectors/packet-netmon.c
@@ -2544,7 +2544,7 @@ void proto_register_netmon(void)
FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }
},
{ &hf_netmon_system_config_tcb_table_partitions,
- { "Tcb table paritions", "netmon_system_config.tcb_table_partitions",
+ { "Tcb table partitions", "netmon_system_config.tcb_table_partitions",
FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }
},
{ &hf_netmon_system_config_max_hash_table_size,
diff --git a/epan/dissectors/packet-nfapi.c b/epan/dissectors/packet-nfapi.c
index c04bcc0487..649536d92e 100644
--- a/epan/dissectors/packet-nfapi.c
+++ b/epan/dissectors/packet-nfapi.c
@@ -2372,7 +2372,7 @@ static void dissect_cyclic_shift_1_for_drms_value(ptvcursor_t * ptvc, packet_inf
expert_add_info_format(pinfo, item, &ei_invalid_range, "Invalid cyclic shift 1 for drms value [0..7]");
}
}
-static void dissect_tdd_subframe_assignement_value(ptvcursor_t * ptvc, packet_info* pinfo)
+static void dissect_tdd_subframe_assignment_value(ptvcursor_t * ptvc, packet_info* pinfo)
{
guint32 test_value;
proto_item* item = ptvcursor_add_ret_uint(ptvc, hf_nfapi_subframe_assignment, 2, ENC_BIG_ENDIAN, &test_value);
@@ -7616,7 +7616,7 @@ static const tlv_t configuration_tags[] =
{ 0x0057, NULL, NULL },
{ 0x0058, NULL, NULL },
{ 0x0059, NULL, NULL },
- { 0x005A, "TDD frame structure config - Subframe assignment", dissect_tdd_subframe_assignement_value },
+ { 0x005A, "TDD frame structure config - Subframe assignment", dissect_tdd_subframe_assignment_value },
{ 0x005B, "TDD frame structure config - Special sub-frame patterns", dissect_tdd_subframe_patterns_value },
{ 0x005C, NULL, NULL },
{ 0x005D, NULL, NULL },
@@ -7888,8 +7888,8 @@ static const tlv_t p7_tags[] =
{ 0x202F, "CQI PDU Release 8", dissect_rx_cqi_indication_rel8_value },
{ 0x2030, "CQI PDU Release 9", dissect_rx_cqi_indication_rel9_value },
{ 0x2031, "RACH Indication Body", dissect_rach_indication_body_value },
- { 0x2032, "Preamable PDU Release 8", dissect_rach_indication_rel8_value },
- { 0x2033, "Preamable PDU Release 9", dissect_rach_indication_rel9_value },
+ { 0x2032, "Preamble PDU Release 8", dissect_rach_indication_rel8_value },
+ { 0x2033, "Preamble PDU Release 9", dissect_rach_indication_rel9_value },
{ 0x2034, "SRS Indication Body", dissect_srs_indication_body_value },
{ 0x2035, "SRS PDU Release 8", dissect_srs_indication_rel8_value },
{ 0x2036, "SRS PDU Release 9", dissect_srs_indication_rel9_value },
@@ -7919,7 +7919,7 @@ static const tlv_t p7_tags[] =
{ 0x204E, "MDPCCH DCI UL PDU Release 13", dissect_hi_dci0_mdpcch_dci_ul_rel13_value },
{ 0x204F, "HARQ PDU Release 13 or later TDD", dissect_harq_indication_rel13_later_tdd_value },
{ 0x2050, "HARQ PDU Release 13 or later FDD", dissect_harq_indication_rel13_later_fdd_value },
- { 0x2051, "Preamable PDU Release 13", dissect_rach_indication_rel13_value },
+ { 0x2051, "Preamble PDU Release 13", dissect_rach_indication_rel13_value },
{ 0x2052, "UL CQI Information", dissect_ul_cqi_information_value },
{ 0x2053, "SRS PDU Release 11", dissect_srs_indication_rel11_value },
{ 0x2054, "TDD Channel Measurement", dissect_tdd_channel_measurement_value },
@@ -9130,7 +9130,7 @@ void proto_register_nfapi(void)
"Enable / Disable PBCH repetitions", HFILL }
},
{ &hf_nfapi_prach_cat_m_root_sequence_index,
- { "PRACH CAT-M Root sequence Index", "nfapi.prach.cat_m.root.squence.index",
+ { "PRACH CAT-M Root sequence Index", "nfapi.prach.cat_m.root.sequence.index",
FT_UINT16, BASE_DEC, NULL, 0x0,
"PRACH Root sequence Index", HFILL }
},
@@ -9544,7 +9544,7 @@ void proto_register_nfapi(void)
{ &hf_nfapi_nmm_uplink_rssi_supported,
{ "NMM Uplink RSSI supported", "nfapi.nmm.uplink.rssi.supported",
FT_UINT8, BASE_DEC, VALS(ul_rssi_supported_vals), 0x0,
- "Indicates if the uplink RSSI meausremnts are supported by NMM.", HFILL }
+ "Indicates if the uplink RSSI meausurements are supported by NMM.", HFILL }
},
{ &hf_nfapi_minimum_transmit_power,
{ "Minimum transmit power", "nfapi.minimum_transmit_power",
@@ -9637,7 +9637,7 @@ void proto_register_nfapi(void)
"Equivalent to csi-SubframeSet-r12 in TS36.306", HFILL }
},
{ &hi_nfapi_enhanced_4tx_codebook,
- { "Enhanced 4TX codebook", "nfapi.pnf.phy_rel12.exhanced_t4x_codebook",
+ { "Enhanced 4TX codebook", "nfapi.pnf.phy_rel12.enhanced_t4x_codebook",
FT_UINT16, BASE_DEC, NULL, 0x0,
"Indicates if PHY supports the enhanced 4TX codebook. Equivalent to enhanced-4TxCodebook-r12 in TS36.306", HFILL }
},
@@ -9692,7 +9692,7 @@ void proto_register_nfapi(void)
"Indicates if PHY supports DL LAA starting in the second slot in a subframe. Equivalent to secondSlotStartingPosition-r13 in TS36.306", HFILL }
},
{ &hf_nfapi_beamforming_supported,
- { "Beamforming Supported", "nfapi.pnf.phy_rel13.beamingforming_supported",
+ { "Beamforming Supported", "nfapi.pnf.phy_rel13.beamforming_supported",
FT_UINT16, BASE_DEC, NULL, 0x0,
"Indicates if PHY supports beamforming (FD-MIMO Class B). Equivalent to beamformed-r13 in TS36.306", HFILL }
},
@@ -10129,7 +10129,7 @@ void proto_register_nfapi(void)
"Number of PRB-pairs constituting the MPDCCH-PRB-pair set", HFILL }
},
{ &hf_nfapi_resource_block_assignment,
- { "Resource Block Assignment", "nfapi.resource.block.assignement",
+ { "Resource Block Assignment", "nfapi.resource.block.assignment",
FT_UINT8, BASE_DEC, NULL, 0x0,
"Combinational Index r", HFILL }
},
@@ -10184,7 +10184,7 @@ void proto_register_nfapi(void)
"Indicates the number of MPDCCH repetitions", HFILL }
},
{ &hf_nfapi_downlink_assignment_index_length,
- { "Downlink assignment Index Length", "nfapi.dl.assignement.index.length",
+ { "Downlink assignment Index Length", "nfapi.dl.assignment.index.length",
FT_UINT8, BASE_DEC, NULL, 0x0,
"Length of Downlink assignment Index field in units of bits.", HFILL }
},
@@ -10204,7 +10204,7 @@ void proto_register_nfapi(void)
"Indicates the Antenna port and, scrambling identity value", HFILL }
},
{ &hf_nfapi_paging_direct_indication_differentiation_flag,
- { "Paging/Direct indication differentiation flag", "nfapi.paging.direct.indictation.differentiation.flag",
+ { "Paging/Direct indication differentiation flag", "nfapi.paging.direct.indication.differentiation.flag",
FT_UINT8, BASE_DEC, VALS(paging_direct_indication_differtiation_flag_vals), 0x0,
"Valid for DCI format 6-2", HFILL }
},
@@ -10338,7 +10338,7 @@ void proto_register_nfapi(void)
"Indicates that PRACH procedure is initiated", HFILL }
},
{ &hf_nfapi_preamble_index,
- { "Preamble Index", "nfapi.preamable.index",
+ { "Preamble Index", "nfapi.preamble.index",
FT_UINT8, BASE_DEC, NULL, 0x0,
"The preamble Index to be used on the PRACH", HFILL }
},
@@ -10594,7 +10594,7 @@ void proto_register_nfapi(void)
"Indicates if the resource blocks allocated for this grant overlap with the SRS configuration.", HFILL }
},
{ &hf_nfapi_disable_sequence_hopping_flag,
- { "Disable seqeunce hopping flag", "nfapi.disable.sequence.hopping.flag",
+ { "Disable sequence hopping flag", "nfapi.disable.sequence.hopping.flag",
FT_UINT8, BASE_DEC, NULL, 0x0,
"Indicates if any configured group hopping should be disabled for this UE.", HFILL }
},
diff --git a/epan/dissectors/packet-nsrp.c b/epan/dissectors/packet-nsrp.c
index 0d05e3da3c..267dc2cfbf 100644
--- a/epan/dissectors/packet-nsrp.c
+++ b/epan/dissectors/packet-nsrp.c
@@ -112,7 +112,7 @@ static const value_string nsrp_msgtype_vals[] = {
};
static const value_string nsrp_flag_vals[] = {
- { 0x80, "ENCRPT MESSAGE" },
+ { 0x80, "ENCRYPT MESSAGE" },
{ 0x40, "CLOSE SESSION" },
{ 0x20, "CHANG SESSION" },
{ 0x10, "CREATE SP SESSION" },
diff --git a/epan/dissectors/packet-obex.c b/epan/dissectors/packet-obex.c
index 0a551b0f71..68314e45a9 100644
--- a/epan/dissectors/packet-obex.c
+++ b/epan/dissectors/packet-obex.c
@@ -3704,7 +3704,7 @@ proto_register_obex(void)
},
{ &hf_profile,
{ "Profile", "obex.profile", FT_UINT32, BASE_DEC | BASE_EXT_STRING, &profile_vals_ext, 0x0,
- "Blutooth Profile used in this OBEX session", HFILL }
+ "Bluetooth Profile used in this OBEX session", HFILL }
},
{ &hf_type,
{ "Type", "obex.type", FT_STRINGZ, STR_ASCII, NULL, 0x0,
diff --git a/epan/dissectors/packet-opa-mad.c b/epan/dissectors/packet-opa-mad.c
index 4e7bb1f89b..f823bbb1dc 100644
--- a/epan/dissectors/packet-opa-mad.c
+++ b/epan/dissectors/packet-opa-mad.c
@@ -2663,8 +2663,8 @@ static void cf_opa_mad_swcongestionsetting_controlmap(gchar *buf, guint32 value)
len = g_snprintf(buf, ITEM_LABEL_LENGTH, "Victim");
if (value & 0x2) /* Credit */
len += g_snprintf(&buf[len], ITEM_LABEL_LENGTH - len, "%sCredit", (len ? ", " : ""));
- if (value & 0x4) /* Thresold & PacketSize */
- len += g_snprintf(&buf[len], ITEM_LABEL_LENGTH - len, "%sThresold & PacketSize", (len ? ", " : ""));
+ if (value & 0x4) /* Threshold & PacketSize */
+ len += g_snprintf(&buf[len], ITEM_LABEL_LENGTH - len, "%sThreshold & PacketSize", (len ? ", " : ""));
if (value & 0x8) /* CS_threshold & CS_ReturnDelay */
len += g_snprintf(&buf[len], ITEM_LABEL_LENGTH - len, "%sCS_threshold & CS_ReturnDelay", (len ? ", " : ""));
if (value & 0x10) /* Marking Rate */
diff --git a/epan/dissectors/packet-pcep.c b/epan/dissectors/packet-pcep.c
index 55e2d4be66..57cf58b331 100644
--- a/epan/dissectors/packet-pcep.c
+++ b/epan/dissectors/packet-pcep.c
@@ -4784,22 +4784,22 @@ proto_register_pcep(void)
{ &hf_pcep_subobj_sr_sid_label,
{ "SID/Label", "pcep.subobj.sr.sid.label",
FT_UINT32, BASE_DEC, NULL, 0xfffff000,
- "SID represent MPLS Lable stack: Lable", HFILL }
+ "SID represent MPLS Label stack: Lable", HFILL }
},
{ &hf_pcep_subobj_sr_sid_tc,
{"SID/TC", "pcep.subobj.sr.sid.tc",
FT_UINT32, BASE_DEC, NULL, 0x00000E00,
- "SID represent MPLS Lable stack: Traffic Class field", HFILL }
+ "SID represent MPLS Label stack: Traffic Class field", HFILL }
},
{ &hf_pcep_subobj_sr_sid_s,
{"SID/S", "pcep.subobj.sr.sid.s",
FT_UINT32, BASE_DEC, NULL, 0x00000100,
- "SID represent MPLS Lable stack: Bottom of Stack", HFILL }
+ "SID represent MPLS Label stack: Bottom of Stack", HFILL }
},
{ &hf_pcep_subobj_sr_sid_ttl,
{"SID/TTL", "pcep.subobj.sr.sid.ttl",
FT_UINT32, BASE_DEC, NULL, 0x0000000FF,
- "SID represent MPLS Lable stack: Time to Live", HFILL }
+ "SID represent MPLS Label stack: Time to Live", HFILL }
},
{ &hf_pcep_subobj_sr_nai_ipv4_node,
{ "NAI (IPv4 Node ID)", "pcep.subobj.sr.nai.ipv4node",
diff --git a/epan/dissectors/packet-isakmp.c b/epan/dissectors/packet-isakmp.c
index 8bb79ae607..5755f47642 100644
--- a/epan/dissectors/packet-isakmp.c
+++ b/epan/dissectors/packet-isakmp.c
@@ -1411,7 +1411,7 @@ static const range_string notifmsg_v2_type[] = {
{ 0,0, NULL },
};
/* 3GPP private error and status types in Notyfy messages
* 3GPP TS 24.302 V16.0.0 (2019-03)
* 3GPP TS 24.502 V15.3.0 (2019-03)
* Note currently all private data types wil be decoded as 3GPP if that's not good enough a preference must be used
@@ -7860,7 +7860,7 @@ proto_register_isakmp(void)
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }},
{ &hf_isakmp_notify_data_3gpp_backoff_timer_len,
- { "Length", "isakmp.notyfy.priv.3gpp.backoff_timer_len",
+ { "Length", "isakmp.notify.priv.3gpp.backoff_timer_len",
FT_UINT8, BASE_DEC, NULL, 0x0,
NULL, HFILL }},
@@ -1411,7 +1411,7 @@ static const range_string notifmsg_v2_type[] = {
{ 0,0, NULL },
};
-/* 3GPP private error and status types in Notyfy messages
+/* 3GPP private error and status types in Notify messages
* 3GPP TS 24.302 V16.0.0 (2019-03)
* 3GPP TS 24.502 V15.3.0 (2019-03)